<script type="text/javascript" src="{{ STATIC_URL }}js/jquery/jquery.slugify.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}js/jquery/moment.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}js/jquery/pikaday.js"></script>