{% extends "sveedocuments/page_details/subbase.html" %}
{% load i18n documents_markup documents_utils %}

{% block sveedocuments_content %}<div{% if page_instance.level == 0 %} class="doc_root_page"{% endif %}>
    {% include "sveedocuments/page_details/_action_menu.html" %}
    {% document_context page_instance %}

    <div class="restructuredtext_container">
        {{ page_instance|document_render }}
    </div>
    
    {% if attachments %}
        {% include 'sveedocuments/page_details/_page_attachments.html' %}
    {% endif %}
</div>{% endblock %}
