{% extends "sveedocuments/board/subbase_inserts.html" %}
{% load i18n documents_menus autobreadcrumb %}

{% block board_content %}
<h2>{% current_title_from_breadcrumbs %}</h2>

<div>
{% pprint_recurse relations %}
</div>

<form action="." method="post">
    {% csrf_token %}
    <div class="buttonHolder panel">
        <input type="submit" name="confirm_delete" value="{% trans "Confirm delete" %}" class="submit button">
    </div>
</form>
{% endblock %}
