{% extends "sveedocuments/base.html" %}
{% load mptt_tags autobreadcrumb %}

{% block sveedocuments_content %}
    <ul class="list-tree">
        {% recursetree page_list %}{% spaceless %}
            <li>
                <div class="tree-node-pointer">
                    <a href="{% url 'sveedocuments:page-details' node.slug %}">{{ node.title }}</a>
                </div>
                {% if not node.is_leaf_node %}
                    <ul class="list-tree">{{ children }}</ul>
                {% endif %}
            </li>
        {% endspaceless %}{% endrecursetree %}
    </ul>
{% endblock %}
